@@ -25,7 +25,7 @@ package Spreadsheet::Read;
 use strict;
 use warnings;
 
-our $VERSION = "0.60";
+our $VERSION = "0.61";
 sub  Version { $VERSION }
 
 use Carp;
@@ -56,7 +56,7 @@ my %can = map { $_->[0] => 0 } @parsers;
 for (@parsers) {
     my ($flag, $mod, $vsn) = @$_;
     $can{$flag} and next;
-    eval "require $mod; qq{$vsn} and ${mod}->VERSION ($vsn); \$can{\$flag} = '$mod'";
+    eval "require $mod; \$vsn and ${mod}->VERSION (\$vsn); \$can{\$flag} = '$mod'";
     #$@ && $@ !~ m{Can't locate} and warn "$mod: $@\n";
     }
 $can{sc} = __PACKAGE__;	# SquirelCalc is built-in
@@ -206,8 +206,8 @@ sub _clipsheets
 	    $ss->{maxrow} && $ss->{maxcol} or next;
 	    foreach my $row (1 .. $ss->{maxrow}) {
 		foreach my $col (1 .. $ss->{maxcol}) {
-		    for (($opt->{cells} ? $ss->{cell}[$col][$row] : ()),
-		         ($opt->{rc} ? $ss->{cr2cell ($col, $row)} : ())) {
+		    for (($opt->{rc}    ? $ss->{cell}   [$col][$row]  : ()),
+		         ($opt->{cells} ? $ss->{cr2cell ($col, $row)} : ())) {
 			defined or next;
 		        $s & 2 and s/\s+$//;
 			$s & 1 and s/^\s+//;
@@ -490,7 +490,7 @@ sub ReadData
 			foreach my $c ($oWkS->{MinCol} .. $sheet{maxcol}) {
 			    my $oWkC = $oWkS->{Cells}[$r][$c] or next;
 			    defined (my $val = $oWkC->{Val})  or next;
-			    $val =~ m/\S/ or next;
+			    $val eq "" and next;
 			    $r > $mr and $mr = $r;
 			    $c > $mc and $mc = $c;
 			    }
@@ -739,12 +739,12 @@ Spreadsheet::Read tries to transparently read *any* spreadsheet and
 return its content in a universal manner independent of the parsing
 module that does the actual spreadsheet scanning.
 
-For OpenOffice and/or LibreOffice this module uses Spreadsheet::ReadSXC
+For OpenOffice and/or LibreOffice this module uses L<Spreadsheet::ReadSXC>
 
-For Microsoft Excel this module uses Spreadsheet::ParseExcel,
-Spreadsheet::ParseXLSX, or Spreadsheet::XLSX.
+For Microsoft Excel this module uses L<Spreadsheet::ParseExcel>,
+L<Spreadsheet::ParseXLSX>, or L<Spreadsheet::XLSX> (discouraged).
 
-For CSV this module uses Text::CSV_XS or Text::CSV_PP.
+For CSV this module uses L<Text::CSV_XS> or L<Text::CSV_PP>.
 
 For SquirrelCalc there is a very simplistic built-in parser
 
@@ -882,12 +882,12 @@ Set quote character for CSV. Default is C<">.
 
 =item dtfmt
 
-Set the format for M$Excel date fields that are set to use the default
+Set the format for MS-Excel date fields that are set to use the default
 date format. The default format in Excel is 'm-d-yy', which is both
 not year 2000 safe, nor very useful. The default is now 'yyyy-mm-dd',
 which is more ISO-like.
 
-Note that date formatting in M$Excel is not reliable at all, as it will
+Note that date formatting in MS-Excel is not reliable at all, as it will
 store/replace/change the date field separator in already stored formats
 if you change your locale settings. So the above mentioned default can
 be either "m-d-yy" OR "m/d/yy" depending on what that specific character
@@ -956,7 +956,7 @@ Note that the indexes in the returned list are 0-based.
 C<row ()> is not imported by default, so either specify it in the
 use argument list, or call it fully qualified.
 
-=item my @row = cellrow ($book, $row)
+=item my @row = cellrow ($sheet, $row)
 
 =item my @row = Spreadsheet::Read::cellrow ($book->[1], 3)
 
@@ -967,7 +967,7 @@ Note that the indexes in the returned list are 0-based.
 C<cellrow ()> is not imported by default, so either specify it in the
 use argument list, or call it fully qualified.
 
-=item my @rows = rows ($book)
+=item my @rows = rows ($sheet)
 
 =item my @rows = Spreadsheet::Read::rows ($book->[1])
 
@@ -1284,6 +1284,9 @@ http://metacpan.org/release/Spreadsheet-ParseXLSX
 
 http://metacpan.org/release/Spreadsheet-XLSX
 
+This module is considered dead and deprecated. It is buggy and unmaintained.
+B<PLEASE> consider to use L</Spradsheet::ParseXLSX> instead.
+
 =item Spreadsheet::ReadSXC
 
 http://metacpan.org/release/Spreadsheet-ReadSXC
